#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bencode
version:              0.6.1.1
visibility:           public
id:                   bencode-0.6.1.1-5Uv6K84thDh1rHlwK6YA4H
key:                  bencode-0.6.1.1-5Uv6K84thDh1rHlwK6YA4H
license:              BSD-3-Clause
copyright:
    (c) 2005-2009, David Himmelstrup,
    (c) 2006 Lemmih <lemmih@gmail.com>,
    (c) 2005 Jesper Louis Andersen <jlouis@mongers.org>

maintainer:           Peter Simons <simons@cryp.to>
author:
    Lemmih <lemmih@gmail.com>,
    Jesper Louis Andersen <jlouis@mongers.org>,
    Christopher Reichert <creichert07@gmail.com>

synopsis:             Parsers and printers for bencoded data.
description:
    Parsers and printers for bencoded data. Bencode (pronounced like B
    encode) is the encoding used by the peer-to-peer file sharing system
    BitTorrent for storing and transmitting loosely structured data.

category:             Text
abi:                  b0a1392b12616685895b0192f74305e9
exposed:              True
exposed-modules:
    Data.BEncode Data.BEncode.Lexer Data.BEncode.Parser
    Data.BEncode.Reader

import-dirs:          /usr/lib/ghc-9.6.6/site-local/bencode-0.6.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bencode-0.6.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bencode-0.6.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bencode
hs-libraries:         HSbencode-0.6.1.1-5Uv6K84thDh1rHlwK6YA4H
depends:
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    parsec-3.1.16.1 transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH

haddock-interfaces:   /usr/share/doc/haskell-bencode/html/bencode.haddock
haddock-html:         /usr/share/doc/haskell-bencode/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

